@@ -143,24 +143,38 @@ array_key_exists("headerTitle", $context)) ? (Twig\Extension\CoreExtension::defa
                 (function() {
                     const BRAND = 'Cause Buzz';
 
-                    // Replace title immediately
                     function applyTitle() {
-                        const t = document.title.trim();
-                        if (t.indexOf(BRAND) === -1) {
+                        let t = document.title.trim();
+
+                        // If Mautic sets \"Something | Mautic\", replace that part
+                        if (t.endsWith('| Mautic')) {
+                            t = t.replace(/\\|\\s*Mautic\$/, '| ' + BRAND);
+                            document.title = t;
+                            return;
+                        }
+
+                        // If the page only sets \"Mautic\" with no prefix
+                        if (t === 'Mautic') {
                             document.title = BRAND;
+                            return;
+                        }
+
+                        // If no brand yet, append it
+                        if (!t.includes(BRAND)) {
+                            document.title = t + ' | ' + BRAND;
                         }
                     }
 
-                    // Run once on initial page load
+                    // Run immediately
                     applyTitle();
 
-                    // Observe title changes (SPA navigation changes title after load)
+                    // Watch for SPA title changes
                     const titleEl = document.querySelector('title');
                     if (titleEl) {
-                        new MutationObserver(applyTitle).observe(titleEl, {childList: true});
+                        new MutationObserver(applyTitle).observe(titleEl, { childList: true });
                     }
 
-                    // Hook into Mautic's internal page load events (super important!)
+                    // Hook into Mautic's SPA navigation
                     if (window.Mautic && typeof window.Mautic.onPageLoad === 'function') {
                         const original = window.Mautic.onPageLoad;
                         window.Mautic.onPageLoad = function(e) {
@@ -169,21 +183,20 @@ array_key_exists("headerTitle", $context)) ? (Twig\Extension\CoreExtension::defa
                         };
                     }
 
-                    // Also hook Stimulus (Mautic 5 admin uses it)
+                    // Stimulus events also change title in Mautic 5
                     document.addEventListener('stimulus:load', applyTitle);
-                    document.addEventListener('DOMContentLoaded', applyTitle);
-                    window.addEventListener('load', applyTitle);
+
                 })();
             </script>
-            
+
             ";
-        // line 97
+        // line 110
         yield $this->extensions['Mautic\CoreBundle\Twig\Extension\AssetExtension']->outputScripts("bodyClose");
         yield "
             ";
-        // line 98
+        // line 111
         yield Twig\Extension\CoreExtension::include($this->env, $context, "@MauticCore/Helper/modal.html.twig", ["id" => "MauticSharedModal", "footerButtons" => true]);
-        // line 101
+        // line 114
         yield "
         </section>
     </body>
@@ -229,7 +242,7 @@ array_key_exists("headerTitle", $context)) ? (Twig\Extension\CoreExtension::defa
      */
     public function getDebugInfo(): array
     {
-        return array (  204 => 40,  197 => 39,  187 => 101,  185 => 98,  181 => 97,  141 => 59,  127 => 47,  125 => 46,  119 => 42,  117 => 39,  107 => 32,  103 => 31,  93 => 24,  86 => 20,  80 => 17,  76 => 16,  72 => 15,  68 => 14,  64 => 13,  60 => 12,  55 => 10,  50 => 7,  48 => 4,  47 => 3,  43 => 1,);
+        return array (  217 => 40,  210 => 39,  200 => 114,  198 => 111,  194 => 110,  141 => 59,  127 => 47,  125 => 46,  119 => 42,  117 => 39,  107 => 32,  103 => 31,  93 => 24,  86 => 20,  80 => 17,  76 => 16,  72 => 15,  68 => 14,  64 => 13,  60 => 12,  55 => 10,  50 => 7,  48 => 4,  47 => 3,  43 => 1,);
     }
 
     public function getSourceContext(): Source
