@@ -290,7 +290,7 @@ Mautic.processPageContent = function (response) {
 
         if (response.route) {
             //update URL in address bar
-            history.pushState(null, \"Cause Buzz\", response.route);
+            history.pushState(null, \"Mautic\", response.route);
 
             //update Title
             Mautic.generatePageTitle( response.route );
